==============================
Terminal Utilities for Tendril
==============================

.. image:: https://img.shields.io/travis/chintal/tendril-utils-terminal.svg
        :target: https://travis-ci.org/chintal/tendril-utils-terminal

.. image:: https://img.shields.io/pypi/v/tendril-utils-terminal.svg
        :target: https://pypi.python.org/pypi/tendril-utils-terminal

* License: AGPLv3
* Documentation: http://tendril-utils-terminal.readthedocs.org


Terminal utilities for Tendril.
